==> sneaky_s0ng-2.0.0a0.tar.gz: sneaky_s0ng-2.0.0a0/README.md <==
# 🎵 Sneaky $0ng 🎵
___
Sneaky $0ng is a music cipher that generates a complex song for you, with a secret message hidden inside. Using MuseScore, as we did, or other music-making applications, Sneaky $0ng can generate sheet music, complete with notations and dynamics. 
Although we can't promise that your cipher will sound good when played, it will be tough to decipher. This is due in part to the complex series of beats utilizing different pitches to create a cipher that is almost impossible for most people to crack. 
___
### REQUIREMENTS.         
To use sneaky $0ng, you need some fundamental programs. 
-  This program must be run in Python3
-  Any musicxml file reader
-  Linux/GitBash needs to be installed
-  You need to have access to the music21 library
___
### INSTILATION & GETTING STARTED.
The installation is easy. You first need to go to Git hub and copy the HTTP to your clipboard
![Screenshot 2024-09-18 145208](https://github.com/user-attachments/assets/ff9936c8-7add-40c5-9343-f2e9e6407c21)

After you have copied the HTTP to your clipboard, you must open up your GitBash or Linux program and Type in. `git clone HTTP`, and you will want to replace the HTTP in `git clone HTTP` with the HTTP link that you copied.

![Screenshot 2024-09-18 145324](https://github.com/user-attachments/assets/7a45f7c6-d41a-4983-8536-b03010999b23)
---
### USING IT. 
Once the repository is installed open music.py and run it, type the sentence you want to encrypt into the terminal when prompted. The program will then update the output.xml file with your encrypted sentence. Open the output.xml file with your musicxml reader to view your code in music notation.

---
### ACCEPTED CHARACTERS
Accepted characters include all letters of the English language "A - Z", German letters (ä, ö, ü, ß), and all numbers "0 - 9" along with the following: 
- ` `
- `,` (commas)
- `.` (periods)
- `?` (question marks)
- `—` (dashes)
- `!` (exclamation marks)
- `:` (colon)
- `;` (semicolons)
- `'` (apostrophe)
- `()` (both parentheses)
- `{}` (both Curley brackets)
- `[]` (both brackets)
- `/` (slashes)
- `$` (dollar signs)
- `%` (percent)
- `"` (quotes)
- `~` (tilda)
-  ` (backticks)
- `@` (AT symbols)
- `#` (pound)
- `^` (carrots)
- `&` (and symbols)
- `*` (stars)
- `_` (underscores)
- `<` (less than symbols)
- `>` (greater than symbols)
- `|` (vertical bar)
- `+` (plus)
- `=` (equals)
---
  *Note - negative numbers are accepted because of the dashes, but they do not have their distinct cipher.*

==> sneaky_s0ng-2.1.1b0.tar.gz: sneaky_s0ng-2.1.1b0/README.md <==
# 🎵 Sneaky S0ng 🎵
___
Sneaky S0ng is a music cipher that generates a complex song for you, with a secret message hidden inside. Using MuseScore, as we did, or other music-making applications, Sneaky $0ng can generate sheet music, complete with notations and dynamics. 
Although we can't promise that your cipher will sound good when played, it will be tough to decipher. This is due in part to the complex series of beats utilizing different pitches to create a cipher that is almost impossible for most people to crack. 
___
### REQUIREMENTS.         
To use sneaky S0ng, you need some fundamental programs. 
-  This program must be run in Python3
-  Any musicxml file reader
-  Linux/GitBash needs to be installed
-  You need to have access to the music21 library
___
### INSTILATION & GETTING STARTED.
The installation is easy. You first need to go to Git hub and copy the HTTP to your clipboard
![Screenshot 2024-09-18 145208](https://github.com/user-attachments/assets/ff9936c8-7add-40c5-9343-f2e9e6407c21)

After you have copied the HTTP to your clipboard, you must open up your GitBash or Linux program and Type in. `git clone HTTP`, and you will want to replace the HTTP in `git clone HTTP` with the HTTP link that you copied.

![Screenshot 2024-09-18 145324](https://github.com/user-attachments/assets/7a45f7c6-d41a-4983-8536-b03010999b23)
---
### USING IT. 
Once the repository is installed open music.py and run it, type the sentence you want to encrypt into the terminal when prompted. The program will then update the output.xml file with your encrypted sentence. Open the output.xml file with your musicxml reader to view your code in music notation.

---
### ACCEPTED CHARACTERS
Accepted characters include all letters of the English language "A - Z", German letters (ä, ö, ü, ß), and all numbers "0 - 9" along with the following: 
- ` `
- `,` (commas)
- `.` (periods)
- `?` (question marks)
- `—` (dashes)
- `!` (exclamation marks)
- `:` (colon)
- `;` (semicolons)
- `'` (apostrophe)
- `()` (both parentheses)
- `{}` (both Curley brackets)
- `[]` (both brackets)
- `/` (slashes)
- `$` (dollar signs)
- `%` (percent)
- `"` (quotes)
- `~` (tilda)
-  ` (backticks)
- `@` (AT symbols)
- `#` (pound)
- `^` (carrots)
- `&` (and symbols)
- `*` (stars)
- `_` (underscores)
- `<` (less than symbols)
- `>` (greater than symbols)
- `|` (vertical bar)
- `+` (plus)
- `=` (equals)
---
  *Note - negative numbers are accepted because of the dashes, but they do not have their distinct cipher.*
